RawTransactionEnvelope

Enum RawTransactionEnvelope 

pub enum RawTransactionEnvelope {
Show 13 variants Payment { signed: Signed<PaymentPayload>, fee: Uint<256, 4>, }, TokenIssue(Signed<TokenIssuePayload>, Address), TokenMint(Signed<TokenMintPayload>), TokenAuthority(Signed<TokenAuthorityPayload>), TokenBlacklist(Signed<TokenBlacklistPayload>), TokenWhitelist(Signed<TokenWhitelistPayload>), TokenPause(Signed<TokenPausePayload>), TokenBurn(Signed<TokenBurnPayload>), TokenClawback(Signed<TokenClawbackPayload>), TokenMetadata(Signed<TokenMetadataUpdatePayload>), TokenBridgeAndMint(Signed<TokenBridgeAndMintPayload>), TokenBurnAndBridge(Signed<TokenBurnAndBridgePayload>), CreateMultiSig(Signed<CreateMultiSigPayload>),
}
The 1Money Network Signed Transaction Payload.

The signed transaction is used to store the transaction payload and the signature that signed by the sender; it’s the core transaction type of the 1Money Network.

Users build the transaction payload and sign it with their private key, and then the payload with the signature formed the transaction request.

Variants



Payment

Payment transaction variant.

payload with the signature signed by the sender.

Fields

fee: Uint<256, 4>


TokenIssue(Signed<TokenIssuePayload>, Address)

Token issue transaction variant.

payload with the signature signed by the sender.



TokenMint(Signed<TokenMintPayload>)

Token mint transaction variant.

payload with the signature signed by the sender.



TokenAuthority(Signed<TokenAuthorityPayload>)

Token authority transaction variant.

payload with the signature signed by the sender.



TokenBlacklist(Signed<TokenBlacklistPayload>)

Token blacklist transaction variant.

payload with the signature signed by the sender.



TokenWhitelist(Signed<TokenWhitelistPayload>)

Token whitelist transaction variant.

payload with the signature signed by the sender.



TokenPause(Signed<TokenPausePayload>)

Token pause transaction variant.

payload with the signature signed by the sender.



TokenBurn(Signed<TokenBurnPayload>)

Token burn transaction variant.

payload with the signature signed by the sender.



TokenClawback(Signed<TokenClawbackPayload>)

Token clawback transaction variant.

payload with the signature signed by the clawback authority.



TokenMetadata(Signed<TokenMetadataUpdatePayload>)

Token metadata transaction variant.

payload with the signature signed by the sender.



TokenBridgeAndMint(Signed<TokenBridgeAndMintPayload>)

Bridge and mint transaction variant.

payload with the signature signed by the sender.



TokenBurnAndBridge(Signed<TokenBurnAndBridgePayload>)

Burn and bridge transaction variant.

payload with the signature signed by the sender.



CreateMultiSig(Signed<CreateMultiSigPayload>)

Create multi-signature account transaction variant.

payload with the signature signed by the sender.

Implementations

Source

impl RawTransactionEnvelope

pub fn tx_hash(&self) -> &FixedBytes<32>

Returns the hash of the signed transaction, if the hash is not initialized, it will be calculated the real hash from the payload and the signature then return.

pub fn slow_hash(&self) -> FixedBytes<32>

pub fn signature(&self) -> &SignatureType

pub fn nonce(&self) -> u64

pub fn value(&self) -> Uint<256, 4>

pub fn chain_id(&self) -> u64

pub fn recipient(&self) -> Option<Address>

pub fn token(&self) -> Address

pub fn token_with_creation(&self) -> (Address, bool)

pub fn as_payment(&self) -> Option<&Signed<PaymentPayload>>

Extract the inner signed transaction for specific payload types

pub fn as_token_mint(&self) -> Option<&Signed<TokenMintPayload>>

pub fn as_token_issue(&self) -> Option<(&Signed<TokenIssuePayload>, &Address)>

pub fn as_token_authority(&self) -> Option<&Signed<TokenAuthorityPayload>>

pub fn as_token_pause(&self) -> Option<&Signed<TokenPausePayload>>

pub fn as_token_burn(&self) -> Option<&Signed<TokenBurnPayload>>

pub fn as_token_clawback(&self) -> Option<&Signed<TokenClawbackPayload>>

pub fn as_token_metadata(&self) -> Option<&Signed<TokenMetadataUpdatePayload>>

pub fn as_blacklist(&self) -> Option<&Signed<TokenBlacklistPayload>>

pub fn as_whitelist(&self) -> Option<&Signed<TokenWhitelistPayload>>