SignerRecoverable

Trait SignerRecoverable 

pub trait SignerRecoverable {
    // Required method
    fn recover_signer(&self) -> Result<Address, SigError>;
}
A trait that can recover the signer of a transaction.

Required Methods

fn recover_signer(&self) -> Result<Address, SigError>

Recover the signer from the transaction payload and the signature.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors